@@ -3,7 +3,7 @@ package Shipwright::Backend::SVN;
 use warnings;
 use strict;
 use Carp;
-use File::Spec;
+use File::Spec::Functions qw/catfile catdir/;
 use Shipwright::Util;
 use File::Temp qw/tempdir/;
 use File::Copy qw/copy/;
@@ -157,8 +157,8 @@ sub _yml {
     }
 
     if ($yml) {
-        my $dir = tempdir( CLEANUP => 1 );
-        my $file = File::Spec->catfile( $dir, $f );
+        my $dir = tempdir( 'shipwright_XXXXXX',  CLEANUP => 1 , TMPDIR => 1);
+        my $file = catfile( $dir, $f );
 
         $self->checkout(
             path   => $p_dir,
@@ -227,8 +227,8 @@ sub _update_file {
     my $latest = shift;
 
     if ( $path =~ m{(.*)/(.*)$} ) {
-        my $dir = tempdir( CLEANUP => 0 );
-        my $file = File::Spec->catfile( $dir, $2 );
+        my $dir = tempdir( 'shipwright_XXXXXX',  CLEANUP => 1 , TMPDIR => 1);
+        my $file = catfile( $dir, $2 );
 
         $self->checkout(
             path   => $1,
