@@ -7,7 +7,7 @@ use Carp;
 use base qw/App::CLI::Command Shipwright::Script/;
 
 use Shipwright;
-use File::Spec;
+use File::Spec::Functions qw/catfile catdir/;
 use Shipwright::Util;
 
 sub run {
